package Data::Riak::Role::HasRiak;
{
  $Data::Riak::Role::HasRiak::VERSION = '1.4';
}

use Moose::Role;
use namespace::autoclean;

has riak => (
    is       => 'ro',
    isa      => 'Data::Riak',
    required => 1
);

1;

__END__

=pod

=head1 NAME

Data::Riak::Role::HasRiak

=head1 VERSION

version 1.4

=head1 AUTHORS

=over 4

=item *

Andrew Nelson <anelson at cpan.org>

=item *

Florian Ragwitz <rafl@debian.org>

=back

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Infinity Interactive.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
